@@ -43,14 +43,14 @@ class ParameterCommand(KuroCommand):
         super().process_response(response_str)
         print(self.response_type)
         if self.response_type == ResponseType.SUCCESS:
-            print("SUCCESS")
             self.response = self.params
         elif self.response_type == ResponseType.NOT_PROCESSED:
-            print("not processed")
-            self.response = response_str[-1:]
+            idx = response_str.find(self.cmd) + len(self.cmd)
+            self.response = response_str[idx:idx + 3]
         else:
             self.response = None
-        print("response" + self.response)
+        logging.debug("response" + str(self.response))
+        print("response" + str(self.response))
 
 class OsdState(Enum):
     NONE = None
@@ -64,8 +64,7 @@ class OsdCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        print("osdCommand " +self.response)
-        self.is_osd_on = OsdState(self.response) == OsdState.ON 
+        self.is_osd_on = OsdState(self.response[1:]) == OsdState.ON 
 
 
 class TurnOnCommand(KuroCommand):
@@ -91,7 +90,7 @@ class VolCommand(KuroCommand):
     
     def process_response(self, response_str):
         super().process_response(response_str)
-        if self.response_type == ResponseType.SUCCESS and self.params == None:
+        if self.response_type == ResponseType.NOT_PROCESSED and self.params == None:
             self.volume = int(response_str[-3:])
         else:
             self.response = None   
@@ -108,7 +107,8 @@ class MutedCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        self.is_muted = MutedState(self.response)    
+        if self.response_type == ResponseType.NOT_PROCESSED and self.params == None:
+            self.is_muted = MutedState(self.response[1:])    
 
 class ChannelDirection(Enum):
     FORWARD = "FWD"
@@ -130,7 +130,7 @@ class InputType(Enum):
     PC = "06"
     ANALOG = "81"
     TERRESTRIAL = "82"
-    DIGITAL = "84"
+    DIGITAL = "83"
     HOME_MEDIA_GALLERY = "88"
 
 class TunerType(Enum):
@@ -163,7 +163,10 @@ class InputCommand(ParameterCommand):
     
     def process_response(self, response):
         super().process_response(response)
-        self.input_type = InputType(self.response)
+        if self.response_type == ResponseType.SUCCESS and self.params == None:
+            self.input_type = InputType.NONE
+        else:
+            self.input_type = InputType(self.response[1:])
 
 
 class MultiScreenStatus(Enum):
@@ -183,7 +186,7 @@ class MultiScreenCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        self.multi_screen_status = MultiScreenStatus(self.response)
+        self.multi_screen_status = MultiScreenStatus(self.response[1:])
 
 #CHN RMC
 class AVSType(Enum):
@@ -207,7 +210,7 @@ class AVSCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        self.avsType = AVSType(self.response)
+        self.avsType = AVSType(self.response[1:])
 
 
 class ScreenMode(Enum):
@@ -230,7 +233,7 @@ class ScreenModeCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        self.screenMode = ScreenMode(self.response)
+        self.screenMode = ScreenMode(self.response[1:])
 
 
 class RemoteCommandType(Enum):
@@ -274,7 +277,7 @@ class RemoteCommand(ParameterCommand):
         super().__init__("RMC", remote_command.value)
 
     def process_response(self, response):
-        super().process_response(response)
+        super().process_response(response[1:])
 
 class PictureOffStatus(Enum):
     NONE = None
@@ -283,9 +286,12 @@ class PictureOffStatus(Enum):
 
 class PictureOffCommand(ParameterCommand):
 
-    def __init__(self, picture_off_status = PictureOffStatus.NONE):
+    def __init__(self, picture_off_status = PictureOffStatus.NONE)
         super().__init__("VMT", picture_off_status.value)
 
     def process_response(self, response):
         super().process_response(response)
-        self.is_muted = PictureOffStatus(self.response)
+        if self.response_type == ResponseType.SUCCESS and self.params == None:
+            self.input_type = PictureOffStatus.NONE
+        else:
+            self.is_muted = PictureOffStatus(self.response[1:])
